@@ -48,6 +48,7 @@ static const char rcsid[] = "$OpenBSD: key.c,v 1.6 2003/06/02 23:36:53 millert E
 #include <syslog.h>
 #include <dirent.h>
 #include <termios.h>
+#include <signal.h>
 
 #include "lp.h"
 #include "extern.h"
@@ -58,7 +59,7 @@ static int
 void	f_cbreak(struct info *);
 void	f_columns(struct info *);
 void	f_dec(struct info *);
-void	f_extproc(struct info *);
+/* void	f_extproc(struct info *); */
 void	f_ispeed(struct info *);
 void	f_nl(struct info *);
 void	f_ospeed(struct info *);
@@ -80,7 +81,6 @@ static struct key {
 	{ "columns",	f_columns,	F_NEEDARG },
 	{ "cooked", 	f_sane,		0 },
 	{ "dec",	f_dec,		0 },
-	{ "extproc",	f_extproc,	F_OFFOK },
 	{ "ispeed",	f_ispeed,	F_NEEDARG },
 	{ "new",	f_tty,		0 },
 	{ "nl",		f_nl,		F_OFFOK },
@@ -165,6 +165,7 @@ f_dec(struct info *ip)
 	ip->set = 1;
 }
 
+/*
 void
 f_extproc(struct info *ip)
 {
@@ -177,6 +178,7 @@ f_extproc(struct info *ip)
 		(void)ioctl(ip->fd, TIOCEXT, &tmp);
 	}
 }
+*/
 
 void
 f_ispeed(struct info *ip)
@@ -238,7 +240,7 @@ f_sane(struct info *ip)
 	ip->t.c_iflag = TTYDEF_IFLAG;
 	ip->t.c_iflag |= ICRNL;
 	/* preserve user-preference flags in lflag */
-#define	LKEEP	(ECHOKE|ECHOE|ECHOK|ECHOPRT|ECHOCTL|ALTWERASE|TOSTOP|NOFLSH)
+#define	LKEEP	(ECHOKE|ECHOE|ECHOK|ECHOPRT|ECHOCTL|TOSTOP|NOFLSH)
 	ip->t.c_lflag = TTYDEF_LFLAG | (ip->t.c_lflag & LKEEP);
 	ip->t.c_oflag = TTYDEF_OFLAG;
 	ip->set = 1;
@@ -249,7 +251,7 @@ f_tty(struct info *ip)
 {
 	int tmp;
 
-	tmp = TTYDISC;
+	tmp = N_TTY;
 	if (ioctl(0, TIOCSETD, &tmp) < 0)
 		syslog(LOG_ERR, "%s: ioctl(TIOCSETD): %m", printer);
 }
