@@ -1,4 +1,4 @@
-/*	$OpenBSD: printjob.c,v 1.40 2005/04/28 10:14:26 moritz Exp $	*/
+/*	$OpenBSD: printjob.c,v 1.44 2007/09/10 14:29:53 tobias Exp $	*/
 /*	$NetBSD: printjob.c,v 1.31 2002/01/21 14:42:30 wiz Exp $	*/
 
 /*
@@ -504,7 +504,7 @@ printit(char *file)
 	/* pass 2 */
 
 pass2:
-	fseek(cfp, 0L, 0);
+	fseek(cfp, 0L, SEEK_SET);
 	while (getcfline(cfp))
 		switch (line[0]) {
 		case 'L':	/* identification line */
@@ -864,7 +864,7 @@ sendit(char *file)
 	/*
 	 * pass 2
 	 */
-	fseek(cfp, 0L, 0);
+	fseek(cfp, 0L, SEEK_SET);
 	while (getcfline(cfp))
 		if (line[0] == 'U' && strchr(line+1, '/') == 0)
 			(void)unlink(line+1);
@@ -1012,7 +1012,7 @@ banner(char *name1, char *name2)
 		(void)write(ofd, "\n\r\n\r", 4);
 		scan_out(ofd, name2, '\0');
 		if (class[0]) {
-			(void)write(ofd,"\n\r\n\r\n\r",6);
+			(void)write(ofd, "\n\r\n\r\n\r", 6);
 			scan_out(ofd, class, '\0');
 		}
 		(void)write(ofd, "\n\r\n\r\n\r\n\r\t\t\t\t\tJob:  ", 19);
@@ -1124,6 +1124,7 @@ sendmail(char *user, int bombed)
 		_exit(0);
 	} else if (s > 0) {				/* parent */
 		dup2(p[1], 1);
+		printf("Auto-Submitted: auto-generated\n");
 		printf("To: %s@%s\n", user, fromhost);
 		printf("Subject: %s printer job \"%s\"\n", printer,
 			*jobname ? jobname : "<unknown>");
@@ -1276,7 +1277,7 @@ init(void)
 		SD = _PATH_DEFSPOOL;
 	if (cgetnum(bp, "du", &DU) < 0)
 		DU = DEFNUID;
-	if (cgetstr(bp,"ff", &FF) == -1)
+	if (cgetstr(bp, "ff", &FF) == -1)
 		FF = DEFFF;
 	if (cgetnum(bp, "pw", &PW) < 0)
 		PW = DEFWIDTH;
@@ -1284,7 +1285,7 @@ init(void)
 	if (cgetnum(bp, "pl", &PL) < 0)
 		PL = DEFLENGTH;
 	(void)snprintf(&length[2], sizeof(length) - 2, "%ld", PL);
-	if (cgetnum(bp,"px", &PX) < 0)
+	if (cgetnum(bp, "px", &PX) < 0)
 		PX = 0;
 	(void)snprintf(&pxwidth[2], sizeof(pxwidth) - 2, "%ld", PX);
 	if (cgetnum(bp, "py", &PY) < 0)
@@ -1565,7 +1566,7 @@ setty(void)
 			syslog(LOG_INFO, "%s: ioctl(TIOCGWINSZ): %m",
 			       printer);
 
-		argv = (char **)malloc(256 * sizeof(char *));
+		argv = (char **)calloc(256, sizeof(char *));
 		if (argv == NULL) {
 			syslog(LOG_ERR, "%s: malloc: %m", printer);
 			exit(1);
