@@ -1,4 +1,4 @@
-/*	$OpenBSD: lpr.c,v 1.39 2006/10/11 20:56:59 deraadt Exp $ */
+/*	$OpenBSD: lpr.c,v 1.41 2007/04/07 21:57:27 stevesk Exp $ */
 /*	$NetBSD: lpr.c,v 1.19 2000/10/11 20:23:52 is Exp $	*/
 
 /*
@@ -46,7 +46,7 @@ static const char copyright[] =
 #if 0
 static const char sccsid[] = "@(#)lpr.c	8.4 (Berkeley) 4/28/95";
 #else
-static const char rcsid[] = "$OpenBSD: lpr.c,v 1.39 2006/10/11 20:56:59 deraadt Exp $";
+static const char rcsid[] = "$OpenBSD: lpr.c,v 1.41 2007/04/07 21:57:27 stevesk Exp $";
 #endif
 #endif /* not lint */
 
@@ -60,6 +60,7 @@ static const char rcsid[] = "$OpenBSD: lpr.c,v 1.39 2006/10/11 20:56:59 deraadt
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <sys/file.h>
+#include <sys/sysmacros.h>
 
 #include <dirent.h>
 #include <errno.h>
@@ -429,7 +430,7 @@ copy(int f, char *n)
 		}
 	}
 	(void)close(fd);
-	if (nc==0 && nr==0) 
+	if (nc == 0 && nr == 0) 
 		warnx("%s: empty input file", f ? n : "stdin");
 	else
 		nact++;
@@ -649,7 +650,7 @@ chkprinter(char *s)
 	cgetstr(bp, "rg", &RG);
 	if (cgetnum(bp, "mx", &MX) < 0)
 		MX = DEFMX;
-	if (cgetnum(bp,"mc", &MC) < 0)
+	if (cgetnum(bp, "mc", &MC) < 0)
 		MC = DEFMAXCOPIES;
 	if (cgetnum(bp, "du", &DU) < 0)
 		DU = DEFNUID;
@@ -718,8 +719,9 @@ usage(void)
 	extern char *__progname;
 
 	fprintf(stderr,
-	    "usage: %s [-cdfghlmnpqrstv] [-Pprinter] [-#num] [-C class] "
-	    "[-J job] [-T title]\n           [-U user] [-i [numcols]] "
-	    "[-1234 font] [-wnum] [name ...]\n", __progname);
+	    "usage: %s [-cdfghlmnpqrstv] [-#num] [-1234 font] "
+	    "[-C class] [-i [numcols]]\n"
+	    "\t[-J job] [-Pprinter] [-T title] [-U user] "
+	    "[-wnum] [name ...]\n", __progname);
 	exit(1);
 }
