@@ -1,5 +1,5 @@
-/*	$OpenBSD: lptest.c,v 1.3 1997/01/17 16:12:48 millert Exp $ */
-/*	$NetBSD: lptest.c,v 1.5 1996/03/21 18:13:20 jtc Exp $	*/
+/*	$OpenBSD: lptest.c,v 1.7 2003/06/02 23:36:53 millert Exp $ */
+/*	$NetBSD: lptest.c,v 1.6 1996/12/09 09:57:50 mrg Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -14,11 +14,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -36,16 +32,16 @@
  */
 
 #ifndef lint
-static char copyright[] =
+static const char copyright[] =
 "@(#) Copyright (c) 1983, 1993\n\
 	The Regents of the University of California.  All rights reserved.\n";
 #endif /* not lint */
 
 #ifndef lint
 #if 0
-static char sccsid[] = "@(#)lptest.c	8.1 (Berkeley) 6/6/93";
+static const char sccsid[] = "@(#)lptest.c	8.1 (Berkeley) 6/6/93";
 #else
-static char rcsid[] = "$OpenBSD: lptest.c,v 1.3 1997/01/17 16:12:48 millert Exp $";
+static const char rcsid[] = "$OpenBSD: lptest.c,v 1.7 2003/06/02 23:36:53 millert Exp $";
 #endif
 #endif /* not lint */
 
@@ -56,12 +52,10 @@ static char rcsid[] = "$OpenBSD: lptest.c,v 1.3 1997/01/17 16:12:48 millert Exp
  * lptest -- line printer test program (and other devices).
  */
 int
-main(argc, argv)
-	int argc;
-	char **argv;
+main(int argc, char **argv)
 {
 	int len, count;
-	register i, j, fc, nc;
+	int i, j, fc, nc;
 	char outbuf[BUFSIZ];
 
 	setbuf(stdout, outbuf);
@@ -85,6 +79,6 @@ main(argc, argv)
 		}
 		putchar('\n');
 	}
-	(void) fflush(stdout);
+	(void)fflush(stdout);
 	exit(0);
 }
